@@ -161,6 +161,13 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
     if ms1_df is None:
         ms1_df, ms2_df = msql_fileloading.load_data(input_filename, cache=cache)
 
+    # Setting types for DF
+    try:
+        ms1_df["scan"] = ms1_df["scan"].astype(int)
+        ms2_df["scan"] = ms2_df["scan"].astype(int)
+    except:
+        pass
+
     # Here we are going to translate the variable query into a concrete query based upon the data
     all_concrete_queries = []
     if variable_properties["has_variable"]:
@@ -168,27 +175,48 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
         presearch_parse = copy.deepcopy(parsed_dict)
         non_variable_conditions = []
         for condition in presearch_parse["conditions"]:
-            for value in condition["value"]:
+            if "value" in condition:
+                for value in condition["value"]:
+                    try:
+                        # Checking if X is in any string
+                        if "X" in value:
+                            continue
+                    except TypeError:
+                        # This is when the target is actually a float
+                        pass
+                    non_variable_conditions.append(condition)
+            elif "min" in condition:
+                min_val = condition["min"]
+                max_val = condition["max"]
                 try:
-                    # Checking if X is in any string
-                    if "X" in value:
+                    if "X" in min_val:
                         continue
                 except TypeError:
                     # This is when the target is actually a float
                     pass
+
+                try:
+                    if "X" in max_val:
+                        continue
+                except TypeError:
+                    # This is when the target is actually a float
+                    pass
+
                 non_variable_conditions.append(condition)
+
         presearch_parse["conditions"] = non_variable_conditions
 
         ms1_df, ms2_df = _executeconditions_query(presearch_parse, input_filename, cache=cache)
         variable_x_ms1_df = ms1_df
 
-        # TODO: Checking if we can prefilter the X variable, if there are conditions
+        # Here we are trying to pre-filter conditions based upon the qualifiers to make the variable search space smaller
         for condition in parsed_dict["conditions"]:
             if not condition["conditiontype"] == "where":
                 continue
 
-            if not "X" in condition["value"]:
-                continue
+            if "value" in condition:
+                if not "X" in condition["value"]:
+                    continue
         
             # Filtering MS1 peaks only to consider contention for X
             if condition["type"] == "ms1mzcondition":
@@ -198,6 +226,8 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
                     (ms1_df["i_norm"] > min_intpercent) & 
                     (ms1_df["i_tic_norm"] > min_tic_percent_intensity)]
 
+            # TODO: Do this for other types of variables
+
         # Here we will start with the smallest mass and then go up
         masses_considered_df_list = []
         if variable_properties["query_ms1"]:
@@ -217,37 +247,74 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
 
         running_max_mz = 0
         for masses_obj in tqdm(masses_list):
-            if running_max_mz > masses_obj["mz"]:
+            mz_val = masses_obj["mz"]
+
+            if running_max_mz > mz_val:
+                continue
+
+            # Cheking the validity of the mz_val
+            if mz_val < variable_properties["min"] or mz_val > variable_properties["max"]:
+                continue
+            mz_val_defect = mz_val - int(mz_val)
+            if mz_val_defect < variable_properties["mindefect"] or mz_val_defect > variable_properties["maxdefect"]:
                 continue
 
             #######################
             # Writing new query
             #######################
             substituted_parse = copy.deepcopy(parsed_dict)
-            mz_val = masses_obj["mz"]
-
+            
             for condition in substituted_parse["conditions"]:
-                for i, value in enumerate(condition["value"]):
-                    # Rewriting the condition value
+                # This is for standard conditions
+                if "value" in condition:
+                    for i, value in enumerate(condition["value"]):
+                        # Rewriting the condition value
+                        try:
+                            if "X" in value:
+                                new_value = math_parser.parse(value).evaluate({
+                                    "X" : mz_val
+                                })
+                                condition["value"][i] = new_value
+                        except TypeError:
+                            # This is when the target is actually a float
+                            pass
+
+                        # Rewriting the qualifier values
+                        try:
+                            if "qualifiers" in condition:
+                                for qualifier in condition["qualifiers"]:
+                                    if "qualifier" in qualifier:
+                                        if "value" in condition["qualifiers"][qualifier]:
+                                            old_value = condition["qualifiers"][qualifier]["value"]
+                                            condition["qualifiers"][qualifier]["value"] = old_value.replace("X", str(mz_val))
+                        except AttributeError:
+                            pass
+                
+                # TODO: For other types of conditions that might include variables
+                if "min" in condition:
+                    # Rewriting the condition min
+                    value = condition["min"]
                     try:
                         if "X" in value:
                             new_value = math_parser.parse(value).evaluate({
                                 "X" : mz_val
                             })
-                            condition["value"][i] = new_value
+                            condition["min"] = new_value
                     except TypeError:
                         # This is when the target is actually a float
                         pass
 
-                    # Rewriting the qualifier values
+                if "max" in condition:
+                    # Rewriting the condition min
+                    value = condition["max"]
                     try:
-                        if "qualifiers" in condition:
-                            for qualifier in condition["qualifiers"]:
-                                if "qualifier" in qualifier:
-                                    if "value" in condition["qualifiers"][qualifier]:
-                                        old_value = condition["qualifiers"][qualifier]["value"]
-                                        condition["qualifiers"][qualifier]["value"] = old_value.replace("X", str(mz_val))
-                    except AttributeError:
+                        if "X" in value:
+                            new_value = math_parser.parse(value).evaluate({
+                                "X" : mz_val
+                            })
+                            condition["max"] = new_value
+                    except TypeError:
+                        # This is when the target is actually a float
                         pass
             
             # Let's consider this mz
@@ -255,11 +322,6 @@ def _evalute_variable_query(parsed_dict, input_filename, cache=True, parallel=Fa
 
             # Checking the x conditions
             substituted_parse["comment"] = str(mz_val)
-            if mz_val < variable_properties["min"] or mz_val > variable_properties["max"]:
-                continue
-            mz_val_defect = mz_val - int(mz_val)
-            if mz_val_defect < variable_properties["mindefect"] or mz_val_defect > variable_properties["maxdefect"]:
-                continue
 
             all_concrete_queries.append(substituted_parse)
     else:
@@ -457,19 +519,17 @@ def _executeconditions_query(parsed_dict, input_filename, ms1_input_df=None, ms2
             if len(ms1_df) == 0:
                 continue
 
-            mz = condition["value"][0]
-            mz_tol = 0.1
-            mz_min = mz - mz_tol
-            mz_max = mz + mz_tol
-            ms1_df = ms1_df[(ms1_df["mz"] > mz_min) & (ms1_df["mz"] < mz_max)]
-
+            # Applying the filters
+            ms1_df = msql_engine_filters.ms1_filter(condition, ms1_df)
             continue
         
         if condition["type"] == "ms2productcondition":
             if len(ms2_df) == 0:
                 continue
 
-            mz = condition["value"][0]
+            # TODO: Refactor into a function
+
+            mz = float(condition["value"][0])
             mz_tol = _get_mz_tolerance(condition.get("qualifiers", None), mz)
             mz_min = mz - mz_tol
             mz_max = mz + mz_tol
@@ -635,4 +695,28 @@ def _executecollate_query(parsed_dict, ms1_df, ms2_df):
 
                 return ms2_df
 
+        if parsed_dict["querytype"]["function"] == "functionscanmaxint":
+            # This is the biggest peak in the spectrum
+
+            if parsed_dict["querytype"]["datatype"] == "datams1data":
+                if len(ms1_df) == 0:
+                    return ms1_df
+
+                ms1sum_df = ms1_df.groupby("scan").max().reset_index()
+
+                ms1_df = ms1_df.groupby("scan").first().reset_index()
+                ms1_df["i"] = ms1sum_df["i"]
+
+                return ms1_df
+            if parsed_dict["querytype"]["datatype"] == "datams2data":
+                if len(ms2_df) == 0:
+                    return ms2_df
+
+                ms2sum_df = ms2_df.groupby("scan").max().reset_index()
+                
+                ms2_df = ms2_df.groupby("scan").first().reset_index()
+                ms2_df["i"] = ms2sum_df["i"]
+
+                return ms2_df
+
         print("APPLYING FUNCTION")    
