@@ -49,6 +49,12 @@ class MassQLToJSON(Transformer):
 
    def qualifierintensityreference(self, items):
       return "qualifierintensityreference"
+   
+   def qualifierexclude(self, items):
+      return "qualifierexcluded"
+
+   def qualifiercardinality(self, items):
+      return "qualifiercardinality"
 
    def ms2productcondition(self, items):
       return "ms2productcondition"
@@ -98,6 +104,9 @@ class MassQLToJSON(Transformer):
    def xdefect(self, items):
       return "xdefect"
 
+   def qualifiermassdefect(self, items):
+      return "qualifiermassdefect"
+
    # Handling mobility literals
    def mobilitycondition(self, items):
       return "mobilitycondition"
@@ -116,6 +125,14 @@ class MassQLToJSON(Transformer):
          qualifier_dict["type"] = "qualifier"
          qualifier_dict[qualifier_type] = {}
          qualifier_dict[qualifier_type]["name"] = qualifier_type
+      
+      if len(items) == 1 and items[0] == "qualifierexcluded":
+         qualifier_type = items[0]
+         
+         qualifier_dict = {}
+         qualifier_dict["type"] = "qualifier"
+         qualifier_dict[qualifier_type] = {}
+         qualifier_dict[qualifier_type]["name"] = qualifier_type
 
       # We are at a qualifier leaf
       if len(items) == 3:
@@ -145,6 +162,18 @@ class MassQLToJSON(Transformer):
             for key in qualifier:
                qualifier_dict[key] = qualifier[key]
 
+      if len(items) == 5:
+         # This is mass defect
+         qualifier_type = items[0]
+
+         if qualifier_type == "qualifiermassdefect" or qualifier_type == "qualifiercardinality":
+            qualifier_dict = {}
+            qualifier_dict["type"] = "qualifier"
+            qualifier_dict[qualifier_type] = {}
+            qualifier_dict[qualifier_type]["name"] = qualifier_type
+            qualifier_dict[qualifier_type]["min"] = items[-2]
+            qualifier_dict[qualifier_type]["max"] = items[-1]
+
       return qualifier_dict
 
    def conditionfields(self, items):
@@ -153,22 +182,23 @@ class MassQLToJSON(Transformer):
    def condition(self, items):
       condition_type = items[0]
 
-      if len(items) == 2:
-         # These are most queries, with a numericalexpression
-         condition_dict = {}
-         condition_dict["type"] = condition_type
-         condition_dict["value"] = [items[-1]]
-      elif len(items) == 3:
-         # These are for polarity or numerical expression
+      if len(items) == 3:
+         # These are for or numerical expression polarity or numerical expression
          if condition_type == "polaritycondition":
             condition_dict = {}
             condition_dict["type"] = items[0]
             condition_dict["value"] = [items[-1]]
          else:
             # These are numerical expressions for mz,rt type conditions
-            condition_dict = {}
-            condition_dict["type"] = items[0]
-            condition_dict["value"] = items[-1]
+            # This might be an item or could be a list
+            if isinstance(items[-1], list):
+               condition_dict = {}
+               condition_dict["type"] = items[0]
+               condition_dict["value"] = items[-1]
+            else:
+               condition_dict = {}
+               condition_dict["type"] = items[0]
+               condition_dict["value"] = [items[-1]]
       elif len(items) == 5:
          # These are for the x range clauses
          if items[0] == "xcondition":
@@ -191,8 +221,8 @@ class MassQLToJSON(Transformer):
             condition_dict["type"] = condition_type
 
             if function == "mobilityrange":
-               condition_dict["min"] = float(items[-2])
-               condition_dict["max"] = float(items[-1])
+               condition_dict["min"] = items[-2]
+               condition_dict["max"] = items[-1]
    
       return condition_dict
 
@@ -308,6 +338,9 @@ class MassQLToJSON(Transformer):
    def variable(self, s):
       return s[0].value
 
+   def wildcard(self, s):
+      return "ANY"
+
    # Handling Numerical Expressions
    def plus(self, s):
       return "+"
