@@ -10,7 +10,7 @@ def translate_query(query, language="english"):
         if language == "english":
             sentences.append("The following conditions are applied to find scans in the mass spec data.")
         if language == "russian":
-            sentences.append("Применяются следующие условия для поиска экземпляров в массиве данных.")
+            sentences.append("Следующие условия применяются для поиска соответствий в данных масс спектрометрии.")
         elif language == "korean":
             sentences.append("매스 스펙트럼으로 부터의 스캔 검색조건은 아래와 같습니다.")
         elif language == "chinese":
@@ -43,7 +43,7 @@ def _translate_querytype(querytype, language="english"):
         if language == "english":
             return "Returning the scan information on {}.".format(ms_level)
         if language == "russian":
-            return "Возвращает информацию о скане на {}.".format(ms_level)
+            return "Возвращает информацию о сканировании на {}.".format(ms_level)
         elif language == "korean":
             return "{} 데이터상의 스캔 정보를 반환합니다.".format(ms_level)
         elif language == "chinese":
@@ -61,7 +61,7 @@ def _translate_querytype(querytype, language="english"):
         if language == "english":
             return "Returning the summed scan information on {}.".format(ms_level)
         if language == "russian":
-            return "Возвращает информацию о суммированном скане на {}.".format(ms_level)
+            return "Возвращает информацию о суммированном сканировании на {}.".format(ms_level)
         elif language == "korean":
             return "스칼라를 {} 데이터로 더하기.".format(ms_level)
         elif language == "chinese":
@@ -86,76 +86,92 @@ def _translate_condition(condition, language="english"):
         qualifier_string = ""
 
     if condition["type"] == "ms2productcondition":
+        # Handling multiple values
+        value_list_str = [str(value) for value in condition["value"]]
+        all_values_string = " or ".join(value_list_str)
+
         if language == "english":
-            return "Finding MS2 peak at m/z {}{}.".format(condition["value"][0], qualifier_string) #TODO: add qualifiers
+            return "Finding MS2 peak at m/z {}{}.".format(all_values_string, qualifier_string) #TODO: add qualifiers
         if language == "russian":
-            return "Поиск MS2 пика по m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Поиск MS2 пика по m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "korean":
-            return "MS2 질량대 전하비 (m/z): {} {}.".format(condition["value"][0], qualifier_string)
+            return "MS2 질량대 전하비 (m/z): {} {}.".format(all_values_string, qualifier_string)
         elif language == "chinese":
-            return "寻找m/z{}的MS2峰{}".format(condition["value"][0], qualifier_string)
+            return "寻找m/z{}的MS2峰{}".format(all_values_string, qualifier_string)
         elif language == "french":
-            return "Trouver un pic MS2 à m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Trouver un pic MS2 à m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "german":
-            return "Hat MS2 Signal bei m/z {} {}.".format(condition["value"][0], qualifier_string)
+            return "Hat MS2 Signal bei m/z {} {}.".format(all_values_string, qualifier_string)
         elif language == "spanish":
-            return "Encontrando pico de MS2 a m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Encontrando pico de MS2 a m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "portuguese":
-            return "Buscando ions de MS2 de m/z {} {}.".format(condition["value"][0], qualifier_string)
+            return "Buscando ions de MS2 de m/z {} {}.".format(all_values_string, qualifier_string)
 
     if condition["type"] == "ms2neutrallosscondition":
+        # Handling multiple values
+        value_list_str = [str(value) for value in condition["value"]]
+        all_values_string = " or ".join(value_list_str)
+
         if language == "english":
-            return "Finding MS2 neutral loss peak at m/z {}{}.".format(condition["value"][0], qualifier_string) #TODO: add qualifiers
+            return "Finding MS2 neutral loss peak at m/z {}{}.".format(all_values_string, qualifier_string) #TODO: add qualifiers
         if language == "russian":
-            return "Поиск MS2 нейтраллизации пика по m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Поиск MS2 пика нейтральной потери по m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "korean":
-            return "MS2 전자 소모량 {} {}.".format(condition["value"][0], qualifier_string)
+            return "MS2 전자 소모량 {} {}.".format(all_values_string, qualifier_string)
         elif language == "chinese":
-            return "在{}的MS2中探测到m/z{}".format(condition["value"][0], qualifier_string)
+            return "在{}的MS2中探测到m/z{}".format(all_values_string, qualifier_string)
         elif language == "french":
-            return "Trouver un pic MS2 neutral loss à m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Trouver un pic MS2 neutral loss à m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "german":
-            return "Hat MS2 Neutralverlust von m/z {} {}.".format(condition["value"][0], qualifier_string)
+            return "Hat MS2 Neutralverlust von m/z {} {}.".format(all_values_string, qualifier_string)
         elif language == "spanish":
-            return "Encontrando pico de MS2 de neutral loss en m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Encontrando pico de MS2 de neutral loss en m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "portuguese":
-            return "Encontrando peak de neutralização MS2 na m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Encontrando peak de neutralização MS2 na m/z {}{}.".format(all_values_string, qualifier_string)
     
     if condition["type"] == "ms1mzcondition":
+        # Handling multiple values
+        value_list_str = [str(value) for value in condition["value"]]
+        all_values_string = " or ".join(value_list_str)
+
         if language == "english":
-            return "Finding MS1 peak at m/z {}{}.".format(condition["value"][0], qualifier_string) #TODO: add qualifiers]
+            return "Finding MS1 peak at m/z {}{}.".format(all_values_string, qualifier_string) #TODO: add qualifiers]
         if language == "russian":
-            return "Поиск MS1 пика по m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Поиск MS1 пика по m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "korean":
-            return "MS1 파워 밀도 {} {}.".format(condition["value"][0], qualifier_string)
+            return "MS1 파워 밀도 {} {}.".format(all_values_string, qualifier_string)
         elif language == "chinese":
-            return "在{}的MS1中找到m/z{}".format(condition["value"][0], qualifier_string)
+            return "在{}的MS1中找到m/z{}".format(all_values_string, qualifier_string)
         elif language == "french":
-            return "Trouver un pic MS1 à m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Trouver un pic MS1 à m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "german":
-            return "Hat MS1 Signal bei m/z {} {}.".format(condition["value"][0], qualifier_string)
+            return "Hat MS1 Signal bei m/z {} {}.".format(all_values_string, qualifier_string)
         elif language == "spanish":
-            return "Encontrando pico de MS1 en m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Encontrando pico de MS1 en m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "portuguese":
-            return "Buscando ions de MS1 de m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Buscando ions de MS1 de m/z {}{}.".format(all_values_string, qualifier_string)
     
     if condition["type"] == "ms2precursorcondition":
+        # Handling multiple values
+        value_list_str = [str(value) for value in condition["value"]]
+        all_values_string = " or ".join(value_list_str)
+
         if language == "english":
-            return "Finding MS2 spectra with a precursor m/z {}{}.".format(condition["value"][0], qualifier_string) #TODO: add qualifiers
+            return "Finding MS2 spectra with a precursor m/z {}{}.".format(all_values_string, qualifier_string) #TODO: add qualifiers
         if language == "russian":
-            return "Поиск MS2 по предварительному m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Поиск MS2 спектров по m/z иона-прекурсора {}{}.".format(all_values_string, qualifier_string)
         elif language == "korean":
-            return "MS2 파워 밀도 {} {}.".format(condition["value"][0], qualifier_string)
+            return "MS2 파워 밀도 {} {}.".format(all_values_string, qualifier_string)
         elif language == "chinese":
-            return "在{}的MS2中找到m/z{}".format(condition["value"][0], qualifier_string)
+            return "在{}的MS2中找到m/z{}".format(all_values_string, qualifier_string)
         elif language == "french":
-            return "Trouver des spectres MS2 avec une m/z de précursor {}{}.".format(condition["value"][0], qualifier_string)
+            return "Trouver des spectres MS2 avec une m/z de précursor {}{}.".format(all_values_string, qualifier_string)
         elif language == "german":
-            return "Hat MS2 Vorläuferion bei m/z {} {}.".format(condition["value"][0], qualifier_string)
+            return "Hat MS2 Vorläuferion bei m/z {} {}.".format(all_values_string, qualifier_string)
         elif language == "spanish":
-            return "Encontrando espectros de MS2 con un precursor m/z {}{}.".format(condition["value"][0], qualifier_string)
+            return "Encontrando espectros de MS2 con un precursor m/z {}{}.".format(all_values_string, qualifier_string)
         elif language == "portuguese":
-            return "Buscando espectros MS2 com m/z de referencia {}{}.".format(condition["value"][0], qualifier_string)
+            return "Buscando espectros MS2 com m/z de referencia {}{}.".format(all_values_string, qualifier_string)
 
     return "Translator {} not implemented, contact Ming".format(condition["type"])
 
@@ -168,21 +184,21 @@ def _translate_qualifiers(qualifiers, language="english"):
             qualifier_phrases.append(_translate_qualifier(qualifiers[qualifier], language=language))
     
     if language == "english":
-        return "and ".join(qualifier_phrases)
+        return " and ".join(qualifier_phrases)
     if language == "russian":
-        return "и в".join(qualifier_phrases)
+        return " и в".join(qualifier_phrases)
     elif language == "korean":
-        return "와 ".join(qualifier_phrases)
+        return " 와 ".join(qualifier_phrases)
     elif language == "chinese":
-        return "和 ".join(qualifier_phrases)
+        return " 和 ".join(qualifier_phrases)
     elif language == "french":
-        return "et ".join(qualifier_phrases)
+        return " et ".join(qualifier_phrases)
     elif language == "german":
-        return "und ".join(qualifier_phrases)
+        return " und ".join(qualifier_phrases)
     elif language == "spanish":
-        return "y ".join(qualifier_phrases)
+        return " y ".join(qualifier_phrases)
     elif language == "portuguese":
-        return "e ".join(qualifier_phrases)
+        return " e ".join(qualifier_phrases)
 
     return " and ".join(qualifier_phrases)
 
@@ -227,7 +243,7 @@ def _translate_qualifier(qualifier, language="english"):
         if language == "english":
             return "a minimum percent intensity relative to base peak of {}%".format(qualifier["value"])
         if language == "russian":
-            return "с минимальной процентной интенсивностью {}%".format(qualifier["value"])
+            return "минимальная процентная интенсивность по отношению к базовому пику {}%".format(qualifier["value"])
         elif language == "korean":
             return "최소 정상 높이 {}%".format(qualifier["value"])
         elif language == "chinese":
@@ -241,11 +257,29 @@ def _translate_qualifier(qualifier, language="english"):
         elif language == "portuguese":
             return "uma intensidade mínima relativa ao pico base de {}%".format(qualifier["value"])
 
+    if qualifier["name"] == "qualifierintensityvalue":
+        if language == "english":
+            return "a minimum intensity value {}".format(qualifier["value"])
+        if language == "russian":
+            return "значение минимальной интенсивности {}".format(qualifier["value"])
+        elif language == "korean":
+            return "최소 정상 높이 {}".format(qualifier["value"])
+        elif language == "chinese":
+            return "一个最低比值{}的精确度".format(qualifier["value"])
+        elif language == "french":
+            return "une intensité minimale de {}".format(qualifier["value"])
+        elif language == "german":
+            return "eine minimale Intensität von {}".format(qualifier["value"])
+        elif language == "spanish":
+            return "un mínimo de {} de intensidad".format(qualifier["value"])
+        elif language == "portuguese":
+            return "uma intensidade mínima de {}".format(qualifier["value"])
+
     if qualifier["name"] == "qualifierintensityreference":
         if language == "english":
             return "this peak is used as the intensity reference for other peaks in the spectrum"
         if language == "russian":
-            return "этот пик используется в качестве интенсивности спектра"
+            return "этот пик используется в качестве эталона интенсивности для остальных пиков в спектре"
         elif language == "korean":
             return "이 데이터를 이용해 시퀀스에 다른 데이터를 인식한다"
         elif language == "chinese":
@@ -263,7 +297,7 @@ def _translate_qualifier(qualifier, language="english"):
         if language == "english":
             return "an expected relative intensity to reference peak of {}".format(qualifier["value"]) #TODO: we should likely remove the Y or assume it 1.0
         if language == "russian":
-            return "соответствующая интенсивность {}".format(qualifier["value"])
+            return "ожидаемая относительная интенсивность к ссылаемому пику {}".format(qualifier["value"])
         elif language == "korean":
             return "예상 비율 이용시 이용할 대상 데이터의 정보 {}".format(qualifier["value"])
         elif language == "chinese":
@@ -281,7 +315,7 @@ def _translate_qualifier(qualifier, language="english"):
         if language == "english":
             return "accepting variability of {}% in relative intensity".format(qualifier["value"])
         if language == "russian":
-            return "принимая на случай {}% в относительной интенсивности".format(qualifier["value"])
+            return "принимая изменчивость {}% в относительной интенсивности".format(qualifier["value"])
         elif language == "korean":
             return "이상한 {}%의 비율의 신체 이용 허용".format(qualifier["value"])
         elif language == "chinese":
@@ -295,4 +329,6 @@ def _translate_qualifier(qualifier, language="english"):
         elif language == "portuguese":
             return "e aceitando uma variabilidade de {}% da intensidade relativa".format(qualifier["value"])
 
+    
+
     return "Translator {} not implemented, contact Ming".format(qualifier["name"])
